[llvm] r298176 - [LockFileManager] Reduce lock timeout

Bruno Cardoso Lopes via llvm-commits llvm-commits at lists.llvm.org
Fri Mar 17 17:32:35 PDT 2017


Author: bruno
Date: Fri Mar 17 19:32:34 2017
New Revision: 298176

URL: http://llvm.org/viewvc/llvm-project?rev=298176&view=rev
Log:
[LockFileManager] Reduce lock timeout

Go back to behavior pre-r231309 and reduce the timeout from 8 to ~1.5
min now that we have (a) PCMCache mechanism (r298165) and (b) timeout
that doesn't cause a failure, but actually build the module (r298175).

rdar://problem/30297862

Modified:
    llvm/trunk/lib/Support/LockFileManager.cpp

Modified: llvm/trunk/lib/Support/LockFileManager.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Support/LockFileManager.cpp?rev=298176&r1=298175&r2=298176&view=diff
==============================================================================
--- llvm/trunk/lib/Support/LockFileManager.cpp (original)
+++ llvm/trunk/lib/Support/LockFileManager.cpp Fri Mar 17 19:32:34 2017
@@ -304,9 +304,9 @@ LockFileManager::WaitForUnlockResult Loc
   Interval.tv_sec = 0;
   Interval.tv_nsec = 1000000;
 #endif
-  // Don't wait more than five minutes per iteration. Total timeout for the file
-  // to appear is ~8.5 mins.
-  const unsigned MaxSeconds = 5*60;
+  // Don't wait more than 40s per iteration. Total timeout for the file
+  // to appear is ~1.5 minutes.
+  const unsigned MaxSeconds = 40;
   do {
     // Sleep for the designated interval, to allow the owning process time to
     // finish up and remove the lock file.




More information about the llvm-commits mailing list